<td>
    <span class='fa fa-refresh fa-spin fa-fw text-info' ng-if='!row.error && row.sending' alt='{{data.meta.gentranslate.sending}}...' title='{{data.meta.gentranslate.sending}}...'></span>
    <span class='fa fa-envelope-o text-success' ng-if='!row.error && !row.sending && row.sent' alt='{{data.meta.gentranslate.sent}}' title='{{data.meta.gentranslate.sent}}'></span>
    <span class='fa fa-envelope-open-o' ng-if='!row.error && !row.sending && !row.sent' alt='{{data.meta.gentranslate.waiting}}' title='{{data.meta.gentranslate.waiting}}'></span>
    <span ng-if='row.error' alt='{{data.meta.gentranslate.notsent}}' title='{{data.meta.gentranslate.notsent}}' codenerix-html-compile="false|codenerix"></span>
</td>
<td>{{row.priority|codenerix}}</td>
<td>{{row.created|codenerix}}</td>
<td>{{row.efrom|codenerix}}</td>
<td>{{row.eto|codenerix}}</td>
<td>{{row.subject|codenerix}}</td>
<td>{{row.retries|codenerix}}</td>
<td>{{row.next_retry|codenerix}}</td>
<td>{{row.pk|codenerix}}</td>
